@@ -1,27 +1,39 @@
 package Time::Random;
-
-use 5.006;
-use strict;
-use warnings;
-use base 'Import::Export';
+use 5.006; use strict; use warnings; our $VERSION = '0.04';
 use Time::Piece;
-
+use base 'Import::Export';
 our %EX = (
 	time_random => [qw/all/],
 );
 
+sub time_random {
+	my %args = scalar @_ == 1 ? %{ $_[0] } : @_;
+	$args{$_} = $args{$_} 
+		? $args{strptime} 
+			? scalar Time::Piece->strptime($args{$_}, $args{strptime})->epoch
+			: ref $args{$_}
+				? $args{$_}->epoch()
+				: $args{$_}
+		: $_ eq 'to' ? time : ($args{to} - int(rand(86400)))
+	foreach qw/to from/;
+	$args{time} = gmtime($args{to} - int(rand($args{to} - $args{from}))); 
+	$args{strftime} ? $args{time}->strftime($args{strftime}) : $args{time};
+}
+
+1;
+
+__END__
+
 =head1 NAME
 
 Time::Random - Generate a random time in time.
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
-our $VERSION = '0.03';
-
 =head1 SYNOPSIS
 
 	use Time::Random qw/time_random/;
@@ -49,20 +61,6 @@ our $VERSION = '0.03';
  
 =cut
 
-sub time_random {
-	my %args = scalar @_ == 1 ? %{ $_[0] } : @_;
-	$args{$_} = $args{$_} 
-		? $args{strptime} 
-			? Time::Piece->strptime($args{$_}, $args{strptime})->epoch
-			: ref $args{$_}
-				? $args{$_}->epoch()
-				: $args{$_}
-		: $_ eq 'to' ? time : ($args{to} - int(rand(86400)))
-	foreach qw/to from/;
-	$args{time} = gmtime($args{to} - int(rand($args{to} - $args{from}))); 
-	$args{strftime} ? $args{time}->strftime($args{strftime}) : $args{time};
-}
-
 =head1 AUTHOR
 
 lnation, C<< <thisusedtobeanemail at gmail.com> >>
@@ -148,4 +146,4 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =cut
 
-1; # End of Time::Random
+
